@@ -1,17 +1,18 @@
 #!/bin/sh
 set -ex
-B="$(git describe --tags --exact-match master)"
+B="$(git describe --tags master | sed -e s/-.*//)"
 test -n "$B"
 git push salsa $B
 
-git checkout deb
+git checkout debian
 
-D="$(git describe --tags --exact-match deb || echo '')"
+D="$(git describe --tags --exact-match debian || echo '')"
 if test -z "$D" ; then
 	git-debpush -u AFD79782F3BAEC020B28A19F72CF8E5E25B4C293 --upstream "$B" --remote salsa --quilt=baredebian
-	D="$(git describe --tags --exact-match deb)"
+	D="$(git describe --tags --exact-match debian)"
 fi
 test -n "$D"
+git push salsa $D
 
 T=$(tempfile)
 rm -f $T
